conf.intv: Observed Fisher information based confidence interval of Block-Basu Bivariate
Pareto (BBBVPA) distribution
Description
Observed Fisher information based confidence interval of Bivariate BBBVPA
distribution.
Usage
conf.intv(
object,
conf.lev = 0.95,
tol = 1e-04,
intv.m1 = c(0, 2),
intv.m2 = c(0, 2)
)
Value
A matrix of lower and upper confidence interval limits (in the first and second column respectively).
The matrix rows are labeled by the parameter names (if any) and columns by the corresponding
distribution quantiles.
Arguments
- object
"bbbvpa" class object.
- conf.lev
confidence level, \(0.95\) (default).
- tol
convergence tolerance for confidence intervals, 0.0001 (default).
- intv.m1
interval related to confidence interval of \(\mu_1\), c(0,2) (default).
- intv.m2
interval related to confidence interval of \(\mu_1\), c(0,2) (default).
Author
Biplab Paul <paul.biplab497@gmail.com> and Arabin Kumar Dey <arabin@iitg.ac.in>
Examples
Run this code# see the example of estimation
Run the code above in your browser using DataLab