conf.intv3: Observed Fisher information based confidence interval of 3-parameter Block-Basu
Bivariate Pareto (BBBVPA) distribution
Description
Observed Fisher information based confidence interval of 3-parameter BBBVPA distribution.
Usage
conf.intv3(object, conf.lev = 0.95, tol = 1e-04)
Value
A matrix of lower and upper confidence interval limits (in the first and second column respectively).
The matrix rows are labeled by the parameter names (if any) and columns by the corresponding
distribution quantiles.
Arguments
object
"bbbvpa" class object.
conf.lev
confidence level, \(0.95\) (default).
tol
convergence tolerance for confidence intervals, 0.0001 (default).
Author
Biplab Paul <paul.biplab497@gmail.com> and Arabin Kumar Dey <arabin@iitg.ac.in>